@@ -1,6 +1,7 @@
 import respx
+from httpx import Response
 
-from statuscheck.services.models.statuspageio import STATUS_MINOR
+from statuscheck.services.bases._statuspageio import STATUS_MINOR
 from statuscheck.utils import get_statuscheck_api
 
 
@@ -11,9 +12,7 @@ class TestTwilio:
             mock_response_body = f.read()
         respx.get(
             "https://gpkpyklzq55q.statuspage.io/api/v2/summary.json",
-            status_code=200,
-            content=mock_response_body,
-        )
+        ).mock(return_value=Response(200, content=mock_response_body))
 
         service_name = "twilio"
         service_api = get_statuscheck_api(service_name)
